==> haskell-these-1.1.1.1-271-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 these
version:              1.1.1.1
visibility:           public
id:                   these-1.1.1.1-937taxbfKa84JlSmdXavvz
key:                  these-1.1.1.1-937taxbfKa84JlSmdXavvz
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/isomorphism/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  596329aac4a3cefd7bd2832fec6838d6
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.2.8/site-local/these-1.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/these-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.1.1.1-937taxbfKa84JlSmdXavvz
depends:
    assoc-1.0.2-9jhl4ZSqcxr71crmLLv8zt base-4.16.4.0 binary-0.8.9.0
    deepseq-1.4.6.1 hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-these-1.1.1.1-289-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 these
version:              1.1.1.1
visibility:           public
id:                   these-1.1.1.1-1x10Q8jmJcG5CN0o6q3A0h
key:                  these-1.1.1.1-1x10Q8jmJcG5CN0o6q3A0h
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/isomorphism/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  de2fb9289ef2d1b9092bd9f826d5d3eb
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.2.8/site-local/these-1.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/these-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.1.1.1-1x10Q8jmJcG5CN0o6q3A0h
depends:
    assoc-1.0.2-AkBO2T7hkE91mMAiWEagor base-4.16.4.0 binary-0.8.9.0
    deepseq-1.4.6.1 hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
